( cd usr/X11R6/lib/X11 ; rm -rf app-defaults )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/app-defaults app-defaults )
( cd usr/doc/seyon-2.20c ; rm -rf HOME.seyon.directory.example )
( cd usr/doc/seyon-2.20c ; ln -sf .seyon HOME.seyon.directory.example )
